@@ -178,7 +178,18 @@ def wavedec2(data, wavelet, level: int = None, mode: str = "reflect") -> list:
             Defaults to reflect.
 
     Returns:
-        [list]: List containing the wavelet coefficients.
+        [list]: A list containing the wavelet coefficients.
+
+    Examples:
+        >>> import torch
+        >>> import ptwt, pywt
+        >>> import numpy as np
+        >>> import scipy.misc
+        >>> face = np.transpose(scipy.misc.face(),
+                                [2, 0, 1]).astype(np.float64)
+        >>> pytorch_face = torch.tensor(face).unsqueeze(1)
+        >>> coefficients = ptwt.wavedec2(pytorch_face, pywt.Wavelet("haar"),
+                                         level=2, mode="constant")
     """
     dec_lo, dec_hi, _, _ = get_filter_tensors(
         wavelet, flip=True, device=data.device, dtype=data.dtype)
@@ -208,6 +219,17 @@ def waverec2(coeffs, wavelet):
 
     Returns:
         torch.tensor: The reconstructed signal.
+
+    Examples:
+        >>> import ptwt, pywt, torch
+        >>> import numpy as np
+        >>> import scipy.misc
+        >>> face = np.transpose(scipy.misc.face(),
+                                [2, 0, 1]).astype(np.float64)
+        >>> pytorch_face = torch.tensor(face).unsqueeze(1)
+        >>> coefficients = ptwt.wavedec2(pytorch_face, pywt.Wavelet("haar"),
+                                         level=2, mode="constant")
+        >>> reconstruction = ptwt.waverec2(coefficients, pywt.Wavelet("haar"))
     """
     _, _, rec_lo, rec_hi = get_filter_tensors(
         wavelet, flip=False, device=coeffs[0].device,
@@ -273,6 +295,17 @@ def wavedec(data, wavelet, level: int = None, mode="reflect") -> list:
 
     Returns:
         [list]: A list containing the wavelet coefficients.
+
+    Example:
+        >>> import torch
+        >>> import ptwt, pywt
+        >>> import numpy as np
+        >>> # generate an input of even length.
+        >>> data = np.array([0, 1, 2, 3, 4, 5, 5, 4, 3, 2, 1, 0])
+        >>> data_torch = torch.from_numpy(data.astype(np.float32))
+        >>> # compute the forward fwt coefficients
+        >>> ptwt.wavedec(data_torch, pywt.Wavelet('haar'),
+                         mode='zero', level=2)
     """
     if len(data.shape) == 1:
         # assume time series
@@ -312,6 +345,18 @@ def waverec(coeffs: list, wavelet) -> torch.tensor:
 
     Returns:
         torch.tensor: The reconstructed signal.
+
+    Examples:
+        >>> import torch
+        >>> import ptwt, pywt
+        >>> import numpy as np
+        >>> # generate an input of even length.
+        >>> data = np.array([0, 1, 2, 3, 4, 5, 5, 4, 3, 2, 1, 0])
+        >>> data_torch = torch.from_numpy(data.astype(np.float32))
+        >>> # invert the fast wavelet transform.
+        >>> ptwt.waverec(ptwt.wavedec(data_torch, pywt.Wavelet('haar'),
+                                      mode='zero', level=2),
+                         pywt.Wavelet('haar'))
     """
     _, _, rec_lo, rec_hi = get_filter_tensors(
         wavelet, flip=False, device=coeffs[-1].device,
