@@ -160,8 +160,19 @@ def construct_boundary_s2d(
 class MatrixWavedec2d(object):
     """ Sparse matrix 2d wavelet transform.
         Constructing the sparse fwt-matrix is expensive.
+        For longer wavelets, high level transforms, and large
+        input images this may take a while.
         The matrix is therefore constructed only once and
-        stored in this object for future use.
+        stored in this objects fwt_matrix variable for future use.
+
+    Example:
+        >>> import ptwt, torch, pywt
+        >>> import numpy as np
+        >>> import scipy.misc
+        >>> face = scipy.misc.face()[:256, :256, :].astype(np.float32)
+        >>> pt_face = torch.tensor(face).permute([2, 0, 1])
+        >>> matrixfwt = ptwt.MatrixWavedec2d(pywt.Wavelet("haar"), level=2)
+        >>> mat_coeff = matrixfwt(pt_face)
     """
     def __init__(self, wavelet, level: int,
                  boundary: str = 'qr'):
@@ -170,6 +181,13 @@ class MatrixWavedec2d(object):
         Args:
             wavelet: A pywt wavelet.
             level (int): The level up to which to compute the fwt.
+            boundary (str): The method used for boundary filter treatment.
+                Choose 'qr' or 'gramschmidt'. 'qr' relies on pytorch's
+                dense qr implementation, it is fast but memory hungry.
+                The 'gramschmidt' option is sparse, memory efficient,
+                and slow.
+                Choose 'gramschmidt' if 'qr' runs out of memory.
+                Defaults to 'qr'.
         """
         dec_lo, dec_hi, rec_lo, rec_hi = wavelet.filter_bank
         assert len(dec_lo) == len(dec_hi),\
@@ -279,6 +297,17 @@ class MatrixWaverec2d(object):
         Constructing the fwt matrix is expensive.
         The matrix is, therefore, constructed only
         once and stored for later use.
+
+    Example:
+        >>> import ptwt, torch, pywt
+        >>> import numpy as np
+        >>> import scipy.misc
+        >>> face = scipy.misc.face()[:256, :256, :].astype(np.float32)
+        >>> pt_face = torch.tensor(face).permute([2, 0, 1])
+        >>> matrixfwt = ptwt.MatrixWavedec2d(pywt.Wavelet("haar"), level=2)
+        >>> mat_coeff = matrixfwt(pt_face)
+        >>> matrixifwt = ptwt.MatrixWaverec2d(pywt.Wavelet("haar"))
+        >>> reconstruction = matrixifwt(mat_coeff)
     """
 
     def __init__(self, wavelet, boundary: str = 'qr'):
@@ -287,10 +316,13 @@ class MatrixWaverec2d(object):
 
         Args:
             wavelet: A pywt.Wavelet compatible wavelet object.
+            boundary: The method used to treat the boundary cases.
+                Chosse 'qr' or 'gramschmidt'. Defaults to 'qr'.
         """
         self.wavelet = wavelet
         self.ifwt_matrix = None
         self.level = None
+        self.boundary = boundary
 
     def __call__(self, coefficients: list) -> torch.Tensor:
         """ Compute the inverse matrix 2d fast wavelet transform.
@@ -325,7 +357,8 @@ class MatrixWaverec2d(object):
                 synthesis_matrix_2d = construct_boundary_s2d(
                     self.wavelet, current_height, current_width,
                     dtype=coefficients[-1][0].dtype,
-                    device=coefficients[-1][0].device)
+                    device=coefficients[-1][0].device,
+                    boundary=self.boundary)
                 if s >= 1:
                     synthesis_matrix_2d = cat_sparse_identity_matrix(
                         synthesis_matrix_2d, coefficient_vectors.shape[-1])
